summaryrefslogtreecommitdiffstats
path: root/kolourpaint/widgets/kptoolwidgetbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kolourpaint/widgets/kptoolwidgetbase.h')
-rw-r--r--kolourpaint/widgets/kptoolwidgetbase.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kolourpaint/widgets/kptoolwidgetbase.h b/kolourpaint/widgets/kptoolwidgetbase.h
index 8bef2a67..4afb8d35 100644
--- a/kolourpaint/widgets/kptoolwidgetbase.h
+++ b/kolourpaint/widgets/kptoolwidgetbase.h
@@ -40,14 +40,14 @@
class TQPainter;
// TODO: frame becomes a combobox when its tqparent kpToolToolBar becomes too small
class kpToolWidgetBase : public TQFrame
{
Q_OBJECT
TQ_OBJECT
public:
- kpToolWidgetBase (TQWidget *tqparent, const char *name); // must provide a name for config to work
+ kpToolWidgetBase (TQWidget *parent, const char *name); // must provide a name for config to work
virtual ~kpToolWidgetBase ();
public:
@@ -40,14 +40,14 @@
class TQPainter;
-// TODO: frame becomes a combobox when its tqparent kpToolToolBar becomes too small
+// TODO: frame becomes a combobox when its parent kpToolToolBar becomes too small
class kpToolWidgetBase : public TQFrame
{